@@ -130,6 +130,8 @@ class Workflow:
         return style_list
 
     def __init__(self, task,checkpoint=None,download_path=None,**kwargs):
+        self.demo_input = None
+        self.input_shape = None
         task = task.lower()
         self.task_dict = task_dict
         self.task_nick_name ={
@@ -261,7 +263,16 @@ class Workflow:
             except:
                 os.system("pip install scikit-learn")
                 import joblib
-            self.model = joblib.load(checkpoint)
+            model = joblib.load(checkpoint)
+            if isinstance(model, dict):
+                self.model = model['model']
+                try:
+                    self.demo_input = model['demo_input']
+                    self.input_shape = model['input_shape']
+                except:
+                    pass
+            else:
+                self.model = model
         else:
             assert os.path.exists(checkpoint),ecf.NO_SUCH_CHECKPOINT(checkpoint)
             assert os.path.splitext(checkpoint)[-1]==".onnx",ecf.CHECKPOINT_TYPE(os.path.splitext(checkpoint)[-1].strip("."))
@@ -554,6 +565,12 @@ class Workflow:
         return res
     
     def _baseml_infer(self,data=None, show=None, img_type=None):
+        print(self.input_shape)
+        if data is not None and self.input_shape is not None: 
+            model_input_shape = str(self.input_shape).replace(str(self.input_shape[0]), 'batch')
+            assert type(self.demo_input) == type(data), f"Error Code: -309. The data type {type(data)} doesn't match the model input type {type(self.demo_input)}. Example input: {self.demo_input.tolist()}."
+            assert self.input_shape[1:] == data.shape[1:], f"Error Code: -309. The data shape {data.shape} doesn't match the model input shape {model_input_shape}. Example input: {self.demo_input.tolist()}."
+
         self.baseml_res = self.model.predict(data)
         if img_type is not None:
             dummy_path = os.path.join(os.path.abspath(os.path.dirname(__file__)),'none.jpg')
